==> emf.source_1.0.2_20030326_0335VL.zip: org/eclipse/emf/ecore/util/EcoreEMap.java <==
/**
 * <copyright>
 *
 * Copyright (c) 2002 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * plugins/org.eclipse.emf.ecore/src/org/eclipse/emf/ecore/util/EcoreEMap.java, emf.ecore, org.eclipse.102, 20030326_0335VL
 * @version 1.5 3/26/03
 */
package  org.eclipse.emf.ecore.util;


import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import java.lang.reflect.Array;

import java.util.AbstractCollection;
import java.util.AbstractSet;
import java.util.Collection;
import java.util.ConcurrentModificationException;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;

import org.eclipse.emf.common.notify.NotificationChain;

import org.eclipse.emf.common.util.BasicEList;
import org.eclipse.emf.common.util.BasicEMap;
import org.eclipse.emf.common.util.ECollections;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.common.util.EMap;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.InternalEObject;

import org.eclipse.emf.ecore.impl.EObjectImpl;


public class EcoreEMap extends BasicEMap implements InternalEList
{
  protected EClass entryEClass;
  protected Class entryClass;

  public EcoreEMap(EClass entryEClass, Class entryClass, InternalEObject owner, int featureID)
  {
    this.entryClass = entryClass;
    this.entryEClass = entryEClass;
    delegateEList = new DelegateEObjectContainmentEList(entryClass, owner, featureID);
  }

  protected void initializeDelegateEList()
  {
  }

  protected class DelegateEObjectContainmentEList extends EObjectContainmentEList
  {
    public DelegateEObjectContainmentEList(Class entryClass, InternalEObject owner, int featureID)
    {
      super(entryClass, owner, featureID);
    }

    protected void didAdd(int index, Object newObject)
    {
      doPut((Entry)newObject);
    }

    protected void didSet(int index, Object newObject, Object oldObject)
    {
      didRemove(index, oldObject);
      didAdd(index, newObject);
    }

    protected void didRemove(int index, Object oldObject)
    {
      doRemove((Entry)oldObject);
    }

    protected void didClear(int size, Object [] oldObjects)
    {
      doClear();
    }

    protected void didMove(int index, Object movedObject, int oldIndex)
    {
      doMove((Entry)movedObject);
    }
  }

  protected BasicEList newList()
  {
    return
      new BasicEList()
      {
        public Object [] newData(int listCapacity)
        {
          return (Object [])Array.newInstance(entryClass, listCapacity);
        }
      };
  }

  protected Entry newEntry(int hash, Object key, Object value)
  {
    Entry entry = (Entry)entryEClass.getEPackage().getEFactoryInstance().create(entryEClass);
    entry.setHash(hash);
    entry.setKey(key);
    entry.setValue(value);
    return entry;
  }

  public List basicList()
  {
    return ((InternalEList)delegateEList).basicList();
  }

  /**
   * Returns an iterator that yields unresolved values.
   */
  public Iterator basicIterator()
  {
    return ((InternalEList)delegateEList).basicIterator();
  }

  /**
   * Returns a list iterator that yields unresolved values.
   */
  public ListIterator basicListIterator()
  {
    return ((InternalEList)delegateEList).basicListIterator();
  }

  /**
   * Returns a list iterator that yields unresolved values.
   */
  public ListIterator basicListIterator(int index)
  {
    return ((InternalEList)delegateEList).basicListIterator(index);
  }

  /**
   * Remove the object with without updating the inverse.
   */
  public NotificationChain basicRemove(Object object, NotificationChain notifications)
  {
    return ((InternalEList)delegateEList).basicRemove(object, notifications);
  }

  /**
   * Add the object without updating the inverse.
   */
  public NotificationChain basicAdd(Object object, NotificationChain notifications)
  {
    return ((InternalEList)delegateEList).basicAdd(object, notifications);
  }

  /**
   * Add the object without verifying uniqueness.
   */
  public void addUnique(Object object)
  {
    ((InternalEList)delegateEList).addUnique(object);
  }

  /**
   * Add the object without verifying uniqueness.
   */
  public void addUnique(int index, Object object)
  {
    ((InternalEList)delegateEList).addUnique(index, object);
  }
}

==> emf.source_1.1.0_20030620_1105VL.zip: org/eclipse/emf/ecore/util/EcoreEMap.java <==
/**
 * <copyright>
 *
 * Copyright (c) 2002 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * plugins/org.eclipse.emf.ecore/src/org/eclipse/emf/ecore/util/EcoreEMap.java, emf.ecore, org.eclipse.dev, 20030620_1105VL
 * @version 1.6 6/20/03
 */
package  org.eclipse.emf.ecore.util;


import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import java.lang.reflect.Array;

import java.util.AbstractCollection;
import java.util.AbstractSet;
import java.util.Collection;
import java.util.ConcurrentModificationException;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;

import org.eclipse.emf.common.notify.NotificationChain;

import org.eclipse.emf.common.util.BasicEList;
import org.eclipse.emf.common.util.BasicEMap;
import org.eclipse.emf.common.util.ECollections;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.common.util.EMap;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.InternalEObject;

import org.eclipse.emf.ecore.impl.EObjectImpl;


public class EcoreEMap extends BasicEMap implements InternalEList
{
  protected EClass entryEClass;
  protected Class entryClass;

  public EcoreEMap(EClass entryEClass, Class entryClass, InternalEObject owner, int featureID)
  {
    this.entryClass = entryClass;
    this.entryEClass = entryEClass;
    delegateEList = new DelegateEObjectContainmentEList(entryClass, owner, featureID);
  }

  protected void initializeDelegateEList()
  {
  }

  protected class DelegateEObjectContainmentEList extends EObjectContainmentEList
  {
    public DelegateEObjectContainmentEList(Class entryClass, InternalEObject owner, int featureID)
    {
      super(entryClass, owner, featureID);
    }

    protected void didAdd(int index, Object newObject)
    {
      doPut((Entry)newObject);
    }

    protected void didSet(int index, Object newObject, Object oldObject)
    {
      didRemove(index, oldObject);
      didAdd(index, newObject);
    }

    protected void didRemove(int index, Object oldObject)
    {
      doRemove((Entry)oldObject);
    }

    protected void didClear(int size, Object [] oldObjects)
    {
      doClear();
    }

    protected void didMove(int index, Object movedObject, int oldIndex)
    {
      doMove((Entry)movedObject);
    }
  }

  protected BasicEList newList()
  {
    return
      new BasicEList()
      {
        public Object [] newData(int listCapacity)
        {
          return (Object [])Array.newInstance(entryClass, listCapacity);
        }
      };
  }

  protected Entry newEntry(int hash, Object key, Object value)
  {
    Entry entry = (Entry)entryEClass.getEPackage().getEFactoryInstance().create(entryEClass);
    entry.setHash(hash);
    entry.setKey(key);
    entry.setValue(value);
    return entry;
  }

  public List basicList()
  {
    return ((InternalEList)delegateEList).basicList();
  }

  /**
   * Returns an iterator that yields unresolved values.
   */
  public Iterator basicIterator()
  {
    return ((InternalEList)delegateEList).basicIterator();
  }

  /**
   * Returns a list iterator that yields unresolved values.
   */
  public ListIterator basicListIterator()
  {
    return ((InternalEList)delegateEList).basicListIterator();
  }

  /**
   * Returns a list iterator that yields unresolved values.
   */
  public ListIterator basicListIterator(int index)
  {
    return ((InternalEList)delegateEList).basicListIterator(index);
  }

  /**
   * Remove the object with without updating the inverse.
   */
  public NotificationChain basicRemove(Object object, NotificationChain notifications)
  {
    return ((InternalEList)delegateEList).basicRemove(object, notifications);
  }

  /**
   * Add the object without updating the inverse.
   */
  public NotificationChain basicAdd(Object object, NotificationChain notifications)
  {
    return ((InternalEList)delegateEList).basicAdd(object, notifications);
  }

  /**
   * Add the object without verifying uniqueness.
   */
  public void addUnique(Object object)
  {
    ((InternalEList)delegateEList).addUnique(object);
  }

  /**
   * Add the object without verifying uniqueness.
   */
  public void addUnique(int index, Object object)
  {
    ((InternalEList)delegateEList).addUnique(index, object);
  }

  /**
   * Set the object without verifying uniqueness.
   */
  public Object setUnique(int index, Object object)
  {
    return ((InternalEList)delegateEList).setUnique(index, object);
  }
}
